@@ -19,8 +19,9 @@
 
 
 __all__ = ["autoadapt", "keyb", "mouse", "ntfy", "dlg", "hook", "Icon", "Win",
-    "sendwait", "nfsendwait", "clip", "Dfuncs", "events", "KeyWaiter", "Image",
-    "mp3tag", "sleep", "hotkeys","launch", "Layout","Dpowers", "Dhelpers"]
+    "sendwait", "nfsendwait", "clip", "Dfuncs", "events", "KeyWaiter",
+    "TriggerManager", "Image", "mp3tag", "sleep", "sound","hotkeys","launch",
+    "Layout","Dpowers", "Dhelpers"]
 
 import os, sys
 from time import sleep
@@ -38,15 +39,16 @@ except ModuleNotFoundError:
     import Dhelpers
     
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 from Dhelpers import __version__  as Dhelpers_version
 #Dpowers and Dhelpers share version number
 if __version__ != Dhelpers_version: raise ValueError
 
 from Dhelpers.adaptor import (AdaptorBase, adaptionmethod, AdaptionError,
-    AdaptorBase, adaptionmethod, AdaptiveClass, DependencyManager)
+    AdaptorBase, adaptionmethod, AdaptiveClass)
 from Dhelpers.launcher import launch
-from Dhelpers.customprint import always_print_traceback, restore_print_func
+from Dhelpers.builtin_manipulation import always_print_traceback, \
+    restore_print_func
 from Dhelpers.arghandling import ArgSaver
 from Dhelpers.KeyboardLayouts import Layout
 
@@ -54,16 +56,17 @@ from Dhelpers.KeyboardLayouts import Layout
 try:
     always_print_traceback()
 
-    from .default_backends import backends
+    from . import default_backends
 
     class Adaptor(AdaptorBase):
         """Abstract baseclass for all of Dpower's Adaption classes."""
         #dependency_folder = dependency_folder
-        backend_defaults = backends
         NamedKeyClass = None  #set later
         NamedButtonClass = None  #set later
     
-
+    Adaptor.set_default_backends(default_backends, evaluate_platform=True)
+    
+    DependencyManager = Adaptor.DependencyManager
     activate_autoadapt = Adaptor.activate_autoadapt
     adapt_all = Adaptor.adapt_all
     deactivate_autoadapt = Adaptor.deactivate_autoadapt
@@ -71,40 +74,45 @@ try:
 
 
     from .notificationpower import NotificationAdaptor
-    ntfy = NotificationAdaptor(_primary=True)
+    ntfy = NotificationAdaptor(_primary_name="ntfy")
 
 
     from .windowpower import WindowAdaptor, WindowHandler
     class Win(WindowHandler):
-        adaptor = WindowAdaptor(_primary=True)
+        adaptor = WindowAdaptor(_primary_name="Win.adaptor")
 
     
     from .dialogpower import DialogAdaptor
-    dlg = DialogAdaptor(_primary=True)
+    dlg = DialogAdaptor(_primary_name="dlg")
 
 
     from . import events
     from .events import keyb,mouse,hotkeys,hook, KeyWaiter, \
-        KeyboardAdaptor, MouseAdaptor, HookAdaptor, SenderAdaptor
+        KeyboardAdaptor, MouseAdaptor, HookAdaptor, SenderAdaptor, TriggerManager
 
     from .clipboardpower import ClipboardAdaptor
-    clip = ClipboardAdaptor(_primary=True)
+    clip = ClipboardAdaptor(_primary_name="clip")
 
 
     from .iconpower import IconAdaptor, IconHandler
     class Icon(IconHandler):
-        adaptor = IconAdaptor(_primary=True)
+        adaptor = IconAdaptor(_primary_name="Icon.adaptor")
     
     from . import editing
     from .editing import Image, ImageAdaptor, mp3tag, mp3tagAdaptor
     
+    from . import sound
 
     from . import Dfuncs
     from .Dfuncs import sendwait, nfsendwait
+    
+    from . import winapps
 
 finally:
     restore_print_func()
 
 #clean up this namespace
 del os, AdaptorBase, adaptionmethod, always_print_traceback, \
-    restore_print_func, backends
+    restore_print_func
+
+Adaptor._set_effective_paths(globals(),__name__)
\ No newline at end of file
