@@ -23,11 +23,18 @@ from .mp3power import *
 
 
 class Image(ImageBase):
-    adaptor = ImageAdaptor(_primary=True)
+    adaptor = ImageAdaptor(_primary_name="Image.adaptor")
     
     
 class mp3tag(mp3tagBase):
-    adaptor = mp3tagAdaptor(_primary=True)
-    
-    
-from .FileSelector import *
\ No newline at end of file
+    adaptor = mp3tagAdaptor(_primary_name="mp3tag.adaptor")
+
+
+
+from Dhelpers.file_iteration import FileSelector
+
+
+class playlist_creator(FileSelector):
+    editor_class = mp3tag
+    file_extension = ".m3u"
+    file_start = "#EXTM3U"
\ No newline at end of file
