@@ -16,15 +16,17 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 #
-from Dhelpers.adaptor import DependencyManager
+from ... import DependencyManager
 
-with DependencyManager(__name__) as tester:
-    im_mod = tester.import_module("wand.image", pkg="wand")
+with DependencyManager(__name__) as manager:
+    im_mod = manager.import_module("wand.image", pkg="wand")
 
 Image = im_mod.Image
 
 obj_class = Image
-
+names = {"compr_quality": "compression_quality", "colortype":"type"}
+value_names = {"colortype": im_mod.IMAGE_TYPES, "colorspace":
+    im_mod.COLORSPACE_TYPES, "compression": im_mod.COMPRESSION_TYPES}
 
 def load(file, **kwargs):
     with Image(filename=file, **kwargs) as im:
@@ -52,27 +54,28 @@ def save(obj, destination):
 def close(obj):
     obj.destroy()
 
-def compression(obj, value):
-    if value is None: return obj.compression
-    obj.compression = value
 
-def compr_quality(obj, value):
-    if value is None: return obj.compression_quality
-    obj.compression_quality = value
-    
-def resolution(obj, value):
-    if value is None: return obj.resolution
-    obj.resolution = value
 
-def size(obj, value):
-    if value is None: return obj.size
-    obj.size = value
-    
-def colortype(obj, value):
-    if value is None: return obj.type
-    obj.type = value
 
-# def set_value(backend_obj, name, value = None):
-#     val_before = getattr(backend_obj, name)
-#     if value is None: return val_before
-#     return setattr(backend_obj, name, value)
\ No newline at end of file
+# def compression(obj, value):
+#     if value is None: return obj.compression
+#     obj.compression = value
+#
+# def compr_quality(obj, value):
+#     if value is None: return obj.compression_quality
+#     obj.compression_quality = value
+#
+# def resolution(obj, value):
+#     if value is None: return obj.resolution
+#     obj.resolution = value
+#
+# def size(obj, value):
+#     if value is None: return obj.size
+#     obj.size = value
+#
+# def colortype(obj, value):
+#     if value is None: return obj.type
+#     obj.type = value
+#
+# def resample(obj, value_x, value_y):
+#     return obj.resample(value_x, value_y)
\ No newline at end of file
