@@ -16,31 +16,31 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 #
-from Dhelpers.adaptor import DependencyManager
+from ... import DependencyManager
 
 with DependencyManager(__name__) as tester:
     mp3 = tester.import_module("eyed3.mp3", pkg="eyed3")
 
 import eyed3 #this is already imported and will just place the name here again
 
-obj_class = mp3.Mp3AudioFile
+obj_class = eyed3.id3.tag.Tag
 eyed3.log.setLevel("ERROR")
 
 def load(file, **kwargs):
-    return eyed3.load(file)
+    file = eyed3.load(file)
+    return file.tag
+    
 
 def save(backend_obj, destination):
-    backend_obj.tag.save(destination)
+    backend_obj.save(destination)
 
+def close(backend_obj):
+    pass
 
 def genre(backend_obj, val):
-    t = backend_obj.tag
     if val is None:
-        if t is None: return ""
-        g = backend_obj.tag.genre
+        g = backend_obj.genre
         if g is None: return ""
         return g.name
-    backend_obj.tag.genre = val
+    backend_obj.genre = val
     
-def close(backend_obj):
-    pass
\ No newline at end of file
