@@ -17,10 +17,10 @@
 #
 #
 
-from Dhelpers.adaptor import DependencyManager
+from ... import DependencyManager
 
-with DependencyManager(__name__) as tester:
-    uinput = tester.import_module("evdev_prepared.uinput",pkg="evdev_prepared")
+with DependencyManager(__name__) as manager:
+    uinput = manager.import_module("evdev_prepared.uinput")
 
 global_uinput = uinput.global_uinput
 
