@@ -16,10 +16,10 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 #
-from Dhelpers.adaptor import DependencyManager
+from ... import DependencyManager
 
-with DependencyManager(__name__) as tester:
-    pynput = tester.import_module("pynput", pkg="pynput")
+with DependencyManager(__name__) as manager:
+    pynput = manager.import_module("pynput")
 
 mouse = pynput.mouse.Controller()
 
