@@ -16,12 +16,11 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 #
-from Dhelpers.adaptor import DependencyManager
+from ... import DependencyManager
 
 with DependencyManager(__name__) as tester:
-    uinput = tester.import_module("evdev_prepared.uinput",pkg="evdev_prepared")
-    device_control = tester.import_module("evdev_prepared.device_control",
-            pkg="evdev_prepared")
+    uinput = tester.import_module("evdev_prepared.uinput")
+    device_control = tester.import_module("evdev_prepared.device_control")
 
 global_uinput = uinput.global_uinput
 DeviceSelector = device_control.DeviceSelector
