@@ -27,11 +27,11 @@ from .. import NotificationAdaptor
 
 
 class Waiter(TimedObject):
-    ntfy = NotificationAdaptor(group="waiter", _primary=True)
+    ntfy = NotificationAdaptor(group="waiter", _primary_name="ntfy")
     
     def __init__(self, callback_hook=None, maxlen = None, maxtime = 20, *,
             endevents=(), cond_func=None, eventmap=None,
-            wait=True, capture=False, notify=True):
+            wait=True, capture=False, notify=False):
         super().__init__(timeout=maxtime, wait=wait)
         check_type(CallbackHook, callback_hook)
         if callback_hook: raise ValueError(f"Arguments of callback hook "
@@ -125,10 +125,10 @@ class Waiter(TimedObject):
         
 class KeyWaiter(Waiter, HookAdaptor.AdaptiveClass):
     
-    adaptor = HookAdaptor(group="keywait", _primary=True)
+    adaptor = HookAdaptor(group="keywait", _primary_name="KeyWaiter.adaptor")
     hook = adaptor
-    keyb = KeyboardAdaptor(group="keywait",_primary=True)
-    mouse = MouseAdaptor(group="keywait", _primary=True)
+    keyb = KeyboardAdaptor(group="keywait",_primary_name="keyb")
+    mouse = MouseAdaptor(group="keywait", _primary_name="mouse")
     hotstring_keyb = KeyboardAdaptor(group="hotstring")
 
     def __init__(self, *args, eventmap=None, keys=True,  buttons=False,
@@ -161,6 +161,7 @@ class KeyWaiter(Waiter, HookAdaptor.AdaptiveClass):
         super().__init__(callback_hook, *args, eventmap=eventmap, **kwargs)
     
     def event_condition(self, event, ev_mapped):
+        #print(event)
         if self.join_events:
             self.joined_events += event
             if ev_mapped: self.joined_events_mapped += ev_mapped
@@ -181,12 +182,13 @@ class KeyWaiter(Waiter, HookAdaptor.AdaptiveClass):
 
     @classmethod
     def get1key(cls, maxtime = 2, wait = True, press=True, release=True,
-            capture=True, **options):
+            capture=True, notify=True, **options):
         if wait is not True:
             raise Exception("ERROR: get1 keyword arg 'wait' must be true")
         with hotkeys.paused(3):
             get1 = cls(maxlen=1, maxtime=maxtime, wait=True, press=press,
-                    release = release, capture=capture,**options).start()
+                release = release, capture=capture, notify=notify, **options)
+            get1.start()
         if get1.exitcode == "maxlen":
             key = get1.events[0]
             if not press and not key.press and not options.get("write_rls",
@@ -233,4 +235,12 @@ class KeyWaiter(Waiter, HookAdaptor.AdaptiveClass):
                         inp.joined_events_mapped])
                 else:
                     cls.hotstring_keyb.send(string_dict[inp.joined_events])
-        return inp
\ No newline at end of file
+        return inp
+    
+    @classmethod
+    def wait_for_key(cls, *keynames, timeout=20):
+        inp = cls(maxtime=timeout, endevents=keynames, press=False,
+                release=True, write_rls=False, wait=True)
+        inp.start()
+        if inp.exitcode == "timeout": return False
+        return inp.duration()
\ No newline at end of file
